"""
Context processors for site app
"""
from django.contrib import messages
from django.contrib.sites.shortcuts import get_current_site
from django.core.cache import cache


def info(request):
    """
    Return a SITE_URL and SITE_TITLE template context for the current request.
    """

    cache_key = "site_info_context"
    context_cache = None
    try:
        context_cache = cache.get(cache_key)
    except Exception as err:
        context_cache = None

    if context_cache is None:
        try:
            if request.is_secure():
                scheme = "https://"
            else:
                scheme = "http://"
            current_site = get_current_site(request)
            context = {
                "SITE_URL": scheme + request.get_host(),
                # 'SITE_URL': scheme + current_site.domain,
                "SITE_TITLE": current_site.name,
            }
            context_cache = cache.set(cache_key, context, timeout=86400)
            return context
        except Exception as err:
            messages.error(request, err)
    return context_cache



from django.db import models
from filer.fields.image import FilerImageField
from django.utils.translation import gettext_lazy as _


class Background(models.Model):
    name = models.CharField(verbose_name=_("Background"), max_length=50, null=True)
    image = FilerImageField(null=True, blank=True, on_delete=models.CASCADE)



from django.contrib import admin
from django.contrib.sites.models import Site
from django.contrib.sites.admin import SiteAdmin
from .models import Background


@admin.register(Background)
class BackgroundAdmin(admin.ModelAdmin):
    list_display = ["name"]
    list_display_links = ["name"]
    ordering = ("name",)
    search_fields = ["name"]


class ProxySite(Site):
    """Create Association proxy model for Site Django framework"""

    class Meta:
        proxy = True
        verbose_name = Site._meta.verbose_name
        verbose_name_plural = Site._meta.verbose_name_plural


admin.site.unregister(Site)
admin.site.register(ProxySite, SiteAdmin)



# Generated by Django 4.2.8 on 2023-12-23 18:46

from django.conf import settings
import django.contrib.sites.models
from django.db import migrations, models
import django.db.models.deletion
import filer.fields.image


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ("sites", "0002_alter_domain_unique"),
        migrations.swappable_dependency(settings.FILER_IMAGE_MODEL),
    ]

    operations = [
        migrations.CreateModel(
            name="ProxySite",
            fields=[],
            options={
                "proxy": True,
                "indexes": [],
                "constraints": [],
            },
            bases=("sites.site",),
            managers=[
                ("objects", django.contrib.sites.models.SiteManager()),
            ],
        ),
        migrations.CreateModel(
            name="Background",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                (
                    "name",
                    models.CharField(
                        max_length=50, null=True, verbose_name="Background"
                    ),
                ),
                (
                    "image",
                    filer.fields.image.FilerImageField(
                        blank=True,
                        null=True,
                        on_delete=django.db.models.deletion.CASCADE,
                        to=settings.FILER_IMAGE_MODEL,
                    ),
                ),
            ],
        ),
    ]
